API Documentation
=================

This is a complete list of available methods, along with details about them.

:mod:`fauxfactory`
------------------

.. automodule:: fauxfactory
    :members:

:mod:`fauxfactory.constants`
----------------------------

.. automodule:: fauxfactory.constants
